@@ -305,7 +305,7 @@ class Fs_sip_status extends Safe_CI_Controller
     /**
      * Returns the SIP Channel Status
      */
-    public function channels($page=1)
+    public function channels($offset = '')
     {
         // Set the basic data
         $data['page_title'] = 'SIP Session Status';
@@ -326,25 +326,29 @@ class Fs_sip_status extends Safe_CI_Controller
             $output = NULL;
             $total_calls = 0;
             try {
-                $max_display_record = 50;
-                $init_offset = 0;
-                $params_total = array( 'select' => 'count(*) as total', 'limit' => 1, 'offset' => 0 );
-                $rs_total = $this->_sip_module->api_channels_profile('',$params_total);
-                $page_total = ceil($rs_total[0]->total/$max_display_record);
-                if($page <= 1){
-                    $page = 1;
-                }elseif($page > $page_total){
-                    if($page_total>0){
-                        $page = $page_total;
-                    }else{
-                        $page = 1;
-                    }
-                }
-                $init_offset = ($page - 1) * $max_display_record;
-                $previous_page = $page -1;
-                $next_page = $page + 1;
                 
-                $params = array( 'limit' => $max_display_record, 'offset' => $init_offset );
+                $params_total = array( 'select' => 'count(*) as total', 'limit' => 1, 'offset' => 0 );
+                $rs_total  = $this->_sip_module->api_channels_profile('',$params_total);
+                $record_count =  $rs_total[0]->total;
+                
+                $max_per_page = 20;
+                $data_offset = isset($offset) ? $offset : 0;
+                
+                if ($max_per_page < $record_count) {
+                    $this->load->library('pagination');
+                    $pagination_config['base_url'] = '/SAFe/' . $this->router->fetch_class() . '/' . $this->router->fetch_method() . '/';
+                    $pagination_config['total_rows'] = $record_count;
+                    
+                    $pagination_config['per_page'] = $max_per_page;
+                    $pagination_config['uri_segment'] = 3;
+                    $pieces = explode("/", $_SERVER['REQUEST_URI']);
+                    if(count($pieces) > 5 ){
+                        $pagination_config['uri_segment'] = count($pieces) - 2;
+                    }
+                    $this->pagination->initialize($pagination_config);
+                }
+                
+                $params = array( 'limit' => $max_per_page, 'offset' => $data_offset );
                 $output = $this->_sip_module->api_channels_profile('',$params);
                 if($output!=false){
                     foreach ($output as $chan_info) {
@@ -383,26 +387,15 @@ class Fs_sip_status extends Safe_CI_Controller
                     'Codec',
                     'Call State'
             ));
-                    $table->footer_button = array(
-                                                    array(
-                                                            'url' => base_url('fs_sip_status/channels/'.$page) ,
-                                                            'name' => 'Refresh'
-                                                            )
-                                                    );
-                    if($previous_page >= 1){
-                        array_unshift($table->footer_button, array(
-                                                            'url' => base_url('fs_sip_status/channels/'.$previous_page) ,
-                                                            'name' => 'Prev Page'
-                                                            ));
-                    }
-                    if($next_page > 1 && $next_page <= $page_total){
-                        array_push($table->footer_button, array(
-                        'url' => base_url('fs_sip_status/channels/'.$next_page) ,
-                        'name' => 'Next Page'
-                                ));
-                    }
+                    
+            if (isset($pagination_config)) $table->set_footer($this->pagination->create_links());
                     $data['table'] = $table->generate_table();
         }
+        $data['notif_warn'][] = '<div style="float:left;height:22px;line-height:22px;">&nbsp;&nbsp;</div>'.
+                '<div style="float:left"> Click to Refresh '.safe_button_click("refresh", ucfirst('Refresh') , '/SAFe/' . $this->router->fetch_class() . '/' . $this->router->fetch_method() . '/' .$offset, array(
+                        'float:right;'
+                )).'</div>';
+        
         //Loads the HTML Data
         $this->load->view("safe_header", $data);
         $this->load->view("safe_error");
