@@ -316,7 +316,8 @@ class Safe_module_class extends Safe_object_class
     {
         $data_cfg = $this->get_data_settings();
         if (isset($data_cfg[$data_name]) && true == $data_cfg[$data_name]['filesystem'] && isset($data_cfg[$data_name]['pattern'])) {
-            return count($this->node()->os()->search_files($data_cfg[$data_name]['pattern']));
+            return count($this->node()->os()->search_files(
+                $data_cfg[$data_name]['pattern'],$data_cfg[$data_name]['recursive']));
         }
         return 0;
     }
@@ -332,7 +333,7 @@ class Safe_module_class extends Safe_object_class
         $data_cfg = $this->get_data_settings();
         if (isset($data_cfg[$data_name]) && true == $data_cfg[$data_name]['filesystem'] && isset($data_cfg[$data_name]['pattern'])) {
             $data_files = array();
-            $files = $this->node()->os()->search_files($data_cfg[$data_name]['pattern']);
+            $files = $this->node()->os()->search_files($data_cfg[$data_name]['pattern'], $data_cfg[$data_name]['recursive']);
             foreach ($files as $file) {
                 $data_files[$this->get_data_file_key($data_name, $file) ] = $file;
             }
@@ -363,23 +364,34 @@ class Safe_module_class extends Safe_object_class
      */
     public function get_data_file_content_by_key($data_name, $key, $line_count = NULL, $max_size = NULL)
     {
+        $data_cfg = $this->get_data_settings();
         $content = "";
-        $data_files = $this->get_data_files($data_name);
-        if (isset($data_files[$key])) {
+        $tmp_file_name = pathinfo($key, PATHINFO_FILENAME);
+        if($data_cfg[$data_name]['file_ext']){
+            $tmp_ext = $data_cfg[$data_name]['file_ext'];
+        }else{
+            $tmp_ext = pathinfo($data_cfg[$data_name]['pattern'] , PATHINFO_EXTENSION);
+        }
+        if($data_cfg[$data_name]['file_dir']){
+            $tmp_file_path = $data_cfg[$data_name]['file_dir'];
+        }else{
+            $tmp_file_path = pathinfo($data_cfg[$data_name]['pattern'] , PATHINFO_DIRNAME );
+        }
+        $file = $this->node()->os()->find_file($tmp_file_path, $tmp_file_name.'.'.$tmp_ext, $data_cfg[$data_name]['recursive']);
+        if ($file) {
             // Get data file
-            $data_file = $data_files[$key];
             $os = $this->node()->os();
-            $os->chown_file($data_file, 'webconfig');
+            $os->chown_file($file, 'webconfig');
             // Read content
             if (isset($line_count)) {
                 $os = $this->node()->os();
                 $output = array();
-                $rc = $os->execute('sudo tail -n ' . $line_count . ' ' . $data_file, $output);
+                $rc = $os->execute('sudo tail -n ' . $line_count . ' ' . $file, $output);
                 $content = implode('\n', $output);
             } elseif (isset($max_size)) {
-                $content = file_get_contents($data_file, false, NULL, -1, $max_size);
+                $content = file_get_contents($file, false, NULL, -1, $max_size);
             } else {
-                $content = file_get_contents($data_file);
+                $content = file_get_contents($file);
             }
         }
         return $content;
@@ -396,10 +408,18 @@ class Safe_module_class extends Safe_object_class
     {
         $data_cfg = $this->get_data_settings();
         if (isset($data_cfg[$data_name]) && true == $data_cfg[$data_name]['filesystem'] && isset($data_cfg[$data_name]['pattern'])) {
-            $tmp_file_name = basename($key);
-            $tmp_ext = pathinfo($data_cfg[$data_name]['pattern'] , PATHINFO_EXTENSION);
-            $tmp_file_path = pathinfo($data_cfg[$data_name]['pattern'] , PATHINFO_DIRNAME );
-            return  $this->node()->os()->check_file_exists($tmp_file_path .'/' . $tmp_file_name.'.'.$tmp_ext);
+            $tmp_file_name = pathinfo($key, PATHINFO_FILENAME);
+            if($data_cfg[$data_name]['file_ext']){
+                $tmp_ext = $data_cfg[$data_name]['file_ext'];
+            }else{
+                $tmp_ext = pathinfo($data_cfg[$data_name]['pattern'] , PATHINFO_EXTENSION);
+            }
+            if($data_cfg[$data_name]['file_dir']){
+                $tmp_file_path = $data_cfg[$data_name]['file_dir'];
+            }else{
+                $tmp_file_path = pathinfo($data_cfg[$data_name]['pattern'] , PATHINFO_DIRNAME );
+            }
+            return  $this->node()->os()->check_file_exists($tmp_file_path .'/' . $tmp_file_name.'.'.$tmp_ext, $data_cfg[$data_name]['recursive']);
         }
         throw new Exception('Module ' . $this->description() . ' data_key_exists error for ' . $data_name);
     }
@@ -414,16 +434,28 @@ class Safe_module_class extends Safe_object_class
     {
         $data_cfg = $this->get_data_settings();
         if (isset($data_cfg[$data_name]) && true == $data_cfg[$data_name]['filesystem'] && isset($data_cfg[$data_name]['pattern'])) {
+            // Locate single key ?
             if (isset($data_key)) {
-                $data_files = $this->get_data_files($data_name);
-                if (isset($data_files[$data_key])) $files = array(
-                    $data_files[$data_key]
-                );
-                else return false;
+                $tmp_file_name = pathinfo($data_key, PATHINFO_FILENAME);
+                if($data_cfg[$data_name]['file_ext']){
+                    $tmp_ext = $data_cfg[$data_name]['file_ext'];
+                }else{
+                    $tmp_ext = pathinfo($data_cfg[$data_name]['pattern'] , PATHINFO_EXTENSION);
+                }
+                if($data_cfg[$data_name]['file_dir']){
+                    $tmp_file_path = $data_cfg[$data_name]['file_dir'];
+                }else{
+                    $tmp_file_path = pathinfo($data_cfg[$data_name]['pattern'] , PATHINFO_DIRNAME );
+                }
+                $file = $this->node()->os()->find_file($tmp_file_path, $tmp_file_name.'.'.$tmp_ext, $data_cfg[$data_name]['recursive']);
+                if($file){
+                    $files[] = $file;
+                }
             } else {
                 $data_files = array();
-                $files = $this->node()->os()->search_files($data_cfg[$data_name]['pattern']);
+                $files = $this->node()->os()->search_files($data_cfg[$data_name]['pattern'], $data_cfg[$data_name]['recursive']);
             }
+            // loop to delete selected file(s)
             foreach ($files as $file) {
                 $os = $this->node()->os();
                 $os->chown_file($file, 'webconfig');
