@@ -59,15 +59,60 @@ class Safe_os_wrapper
         if (file_exists($src_file)) Safe_sudo_exec('/bin/mv -f ' . $src_file . ' ' . $dst_file);
         return (file_exists($dst_file));
     }
-    public function search_files($pattern)
+    public function copy_file($src_file, $dst_file)
     {
-        $files = glob($pattern);
-        if (false == $files) return array();
+        if (file_exists($src_file)) Safe_sudo_exec('/bin/cp -f ' . $src_file . ' ' . $dst_file);
+        return (file_exists($dst_file));
+    }
+
+    private function _recursiveGlob($dir, $ext) {
+        $globFiles = array();
+        if(isset($dir) && strlen($dir) && '/' !== $dir){
+            $globFiles = glob("$dir/$ext");
+            $globDirs  = glob("$dir/*", GLOB_ONLYDIR);
+            foreach ($globDirs as $rdir) {
+                $files = $this->_recursiveGlob($rdir, $ext);
+                $globFiles = array_merge($globFiles, $files);
+            }
+        }
+
+        return $globFiles;
+    }
+    
+    public function search_files($pattern, $recursive=false)
+    {
+        if($recursive){
+            $dir = dirname($pattern);
+            $base = basename($pattern);
+            $files = $this->_recursiveGlob($dir, $base);
+        }else{
+            $files = glob($pattern);
+            if (false == $files) $files = array();
+        }
         return $files;
     }
-    public function check_file_exists($file_name)
+    public function check_file_exists($file_name, $recursive=false)
     {
-        return (file_exists($file_name));
+        if($recursive){
+            $dir = dirname($file_name);
+            $base = basename($file_name);
+            $files = $this->_recursiveGlob($dir, $base);
+            return (0 != count($files));
+        }else{
+            return (file_exists($file_name));
+        }
+    }
+    public function find_file($dir, $file_name, $recursive=false)
+    {
+        if($recursive){
+            $files = $this->_recursiveGlob($dir, $file_name);
+        }else{
+            $files = glob("$dir/$file_name");
+        }
+        if(isset($files[0])){
+            return $files[0];
+        }
+        return false;
     }
     public function stat_file($file, &$stats)
     {
@@ -303,6 +348,8 @@ class Safe_centos_wrapper extends Safe_os_wrapper
             break;
 
         default:
+            // Log only default as we don't want to see service xxx status in log
+            error_log('service_ctl('.$service_name.', '.$action.') = '.$return_var);
             $result = safe_sudo_exec('/sbin/service ' . $service_name . ' ' . $action, '', '', $return_var, false);
             break;
         }
